@@ -88,8 +88,7 @@ predict.fnb.multinomial <- function(object, newdata, type = c("class", "raw", "r
   probs <- probs / denom
 
   if (type == "class") {
-    class <- as.factor(object$levels[max.col(probs, ties.method = "first")])
-    levels(class) <- object$levels
+    class <- factor(colnames(probs)[max.col(probs, ties.method = "first")], levels = object$levels)
     return(class)
   }
   return(probs)
